package com.qs.mp.web.controller.api.admin;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.admin.domain.param.ChannelGoodsOrderQueryParam;
import com.qs.mp.channel.domain.ChannelGoodsOrder;
import com.qs.mp.channel.domain.ChannelGoodsOrderItem;
import com.qs.mp.channel.domain.vo.ChannelGoodsOrderItemVO;
import com.qs.mp.channel.domain.vo.ChannelGoodsOrderVO;
import com.qs.mp.channel.service.IChannelGoodsOrderItemService;
import com.qs.mp.channel.service.IChannelGoodsOrderService;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @author zhangkaikai
 * @create 2023-06-05 3:12 PM
 **/

@Api(tags = "门店采购商品订单管理")
@RestController
@RequestMapping("/api/v1/mp/admin/channel/goods/order")
@AllArgsConstructor
public class ChannelGoodsOrderMgrController extends BaseApiController {

    @Autowired
    private IChannelGoodsOrderService channelGoodsOrderService;

    @Autowired
    private IChannelGoodsOrderItemService channelGoodsOrderItemService;

    /**
     * 采购商品订单列表
     */
    @PostMapping("/list")
    @ApiOperation(value = "订单列表", notes = "获取所有订单信息")
    @PreAuthorize("@ss.hasPermi('order:channel:list')")
    @ApiResponses(
            @ApiResponse(code = 200, message = "success", response = ChannelGoodsOrderVO.class)
    )
    public TableDataInfo list(@RequestBody ChannelGoodsOrderQueryParam queryParam) {
        startPage();

        QueryWrapper<ChannelGoodsOrder> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(null != queryParam && StringUtils.isNotBlank(queryParam.getOrderId()), "t1.order_id", queryParam.getOrderId());
        queryWrapper.eq(null != queryParam && null != queryParam.getStatus(), "t1.`status`", queryParam.getStatus());
        queryWrapper.eq(null != queryParam && StringUtils.isNotBlank(queryParam.getTel()), "t1.`tel`", queryParam.getTel());
        queryWrapper.ge(null != queryParam && null != queryParam.getStartTime(), "t1.created_time", queryParam.getStartTime());
        queryWrapper.le(null != queryParam && null != queryParam.getEndTime(), "t1.created_time", queryParam.getEndTime());
        queryWrapper.eq(null != queryParam && null != queryParam.getSupplierId(), "t3.supplier_id", queryParam.getSupplierId());
        queryWrapper.like(null != queryParam && StringUtils.isNotBlank(queryParam.getTitle()), "t2.title", queryParam.getTitle());
        queryWrapper.orderByDesc("t1.created_time", "t1.order_id");
        List<ChannelGoodsOrderVO> list = channelGoodsOrderService.selectChannelGoodsOrderVOList(queryWrapper);
        for (ChannelGoodsOrderVO channelGoodsOrderVO : list) {
            QueryWrapper<ChannelGoodsOrderItem> goodsOrderItemQueryWrapper = new QueryWrapper<>();
            goodsOrderItemQueryWrapper.eq("t1.order_id", channelGoodsOrderVO.getOrderId())
                    .eq(null != queryParam && null != queryParam.getSupplierId(), "t1.supplier_id", queryParam.getSupplierId());
            List<ChannelGoodsOrderItemVO> orderItemVOList = channelGoodsOrderItemService.selectChannelGoodsOrderItemVOList(goodsOrderItemQueryWrapper);
            channelGoodsOrderVO.setItems(orderItemVOList);
        }
        return getDataTable(list);
    }

    /**
     *
     */


}
