package com.qs.mp.web.controller.api.channel;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.admin.domain.Goods;
import com.qs.mp.admin.domain.vo.GoodsVO;
import com.qs.mp.admin.service.IGoodsService;
import com.qs.mp.channel.domain.param.SiteGoodsQueryParam;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import ma.glasnost.orika.MapperFacade;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;


import java.util.List;

/**
 * @author zhangkaikai
 * @create 2023-06-01 5:04 PM
 **/
@Api(tags = "门店采购商品管理")
@RestController
@RequestMapping("/api/v1/mp/channel/*")
@Component
public class ChannelGoodsController extends BaseApiController {

    @Autowired
    private IGoodsService goodsService;

    @Autowired
    private MapperFacade mapperFacade;

    @PostMapping("/site/goods/list")
    @ApiOperation("采购商品列表")
    @ApiResponses(
            @ApiResponse(code = 200, message = "成功", response = GoodsVO.class)
    )
    public TableDataInfo siteGoodsList(@RequestBody SiteGoodsQueryParam param) {

        QueryWrapper<Goods> queryWrapper = new QueryWrapper<Goods>();
        queryWrapper.eq("type", param.getType())
                .orderByDesc("create_time");
        List<Goods> goodsList = goodsService.list(queryWrapper);

        List<GoodsVO> goodsVOList = mapperFacade.mapAsList(goodsList, GoodsVO.class);

        return getDataTable(goodsVOList);
    }

    @PostMapping("/site/goods/detail/{goodsId}")
    @ApiOperation("采购商品详情")
    @ApiResponses(
            @ApiResponse(code = 200, message = "成功", response = GoodsVO.class)
    )
    public AjaxResult siteGoodsDetail(@PathVariable("goodsId") Integer goodsId) {
        Goods goods = goodsService.getById(goodsId);
        GoodsVO goodsVO = mapperFacade.map(goods, GoodsVO.class);
        return AjaxResult.success(goodsVO);
    }







}
